pub struct Reads {
pub opening: Opening,
pub pages: usize,
pub indexes: usize,
}Expand description
What a reader has read, while it was being opened and since.
Fields
opening: OpeningWhat opening cost, before any query had been planned.
pages: usizeWhole stripe pages read since.
indexes: usizeIndex sections read since.